# AUTOGENERATED! DO NOT EDIT! File to edit: ../06_ship_dimensions.ipynb.

# %% auto 0
__all__ = [
    "ShipDimensionsHollenbachSingleScrew",
    "ShipDimensionsHollenbachTwinScrew",
    "ShipDimensionsAddedResistance",
]

# %% ../06_ship_dimensions.ipynb 1
from dataclasses import dataclass


# %% ../06_ship_dimensions.ipynb 3
@dataclass(kw_only=True)
class ShipDimensionsHollenbachSingleScrew:
    """Ship dimensions for Hollenbach single screw ship model."""

    b_beam_m: float
    lpp_length_between_perpendiculars_m: float
    los_length_over_surface_m: float
    lwl_length_water_line_m: float
    cb_block_coefficient: float
    dp_diameter_propeller_m: float
    ta_draft_aft_m: float
    tf_draft_forward_m: float
    wetted_surface_m2: float = None
    av_transverse_area_above_water_line_m2: float = 0
    area_bilge_keel_m2: float = 0
    rho_seawater_kg_per_m3: float = 1025.0  # Seawater density
    rho_air_kg_per_m3: float = 1.225  # Air density at standard conditions (15 deg C)


@dataclass(kw_only=True)
class ShipDimensionsHollenbachTwinScrew:
    """Ship dimensions for Hollenbach twin screw ship model."""

    b_beam_m: float
    lpp_length_between_perpendiculars_m: float
    los_length_over_surface_m: float
    lwl_length_water_line_m: float
    cb_block_coefficient: float
    dp_diameter_propeller_m: float
    ta_draft_aft_m: float
    tf_draft_forward_m: float
    wetted_surface_m2: float = None
    av_transverse_area_above_water_line_m2: float = 0
    area_bilge_keel_m2: float = 0
    rho_seawater_kg_per_m3: float = 1025.0  # Seawater density
    rho_air_kg_per_m3: float = 1.225  # Air density at standard conditions (15 deg C)
    has_bulb: bool = True
    number_rudders: int = 2
    number_shaft_brackets: int = 2
    number_shaft_bossings: int = 2
    number_thrusters: int = 2


@dataclass(kw_only=True)
class ShipDimensionsAddedResistance:
    """Dimensions of a ship according to the STAWAVE2 model

    The default value for kyy_radius_gyration_in_lateral_direction_non_dim is 0.25, which is the
    recommended value from ITTC Recommended Proceduares and Guidelines 7.5-02-07-04.4

    See also: https://ittc.info/media/4180/75-02-07-044.pdf
    """

    b_beam_m: float
    lpp_length_between_perpendiculars_m: float
    cb_block_coefficient: float
    ta_draft_aft_m: float
    tf_draft_forward_m: float
    lwl_length_water_line_m: float = None
    kyy_radius_gyration_in_lateral_direction_non_dim: float = 0.25

    def __post_init__(self):
        if self.lwl_length_water_line_m is None:
            self.lwl_length_water_line_m = self.lpp_length_between_perpendiculars_m

    @property
    def tm_draft_mid_m(self) -> float:
        return 0.5 * (self.ta_draft_aft_m + self.tf_draft_forward_m)
